package com.example.restcalc

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.ViewGroup
import android.widget.Button
import android.widget.EditText
import android.widget.TextView
import android.widget.Toast
import androidx.constraintlayout.widget.ConstraintLayout
import java.security.acl.Group

class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        //connect variables to interface Views
        val etBillAmount = findViewById<EditText>(R.id.etBillAmount)
        val etTipPercentage = findViewById<EditText>(R.id.etTipPercentage)
        val tvTipAmount = findViewById<TextView>(R.id.tvTipAmount)
        val tvTotalAmount = findViewById<TextView>(R.id.tvTotalAmount)
        val btnCalc = findViewById<Button>(R.id.btnCalc)
        val clCalc = findViewById<ConstraintLayout>(R.id.clCalc)

        //declare variables for calculation
        var bill: Double
        var tip: Double
        var total: Double

        // button click listener -- using the implicit approach
        btnCalc.setOnClickListener{
            try {
                bill = etBillAmount.text.toString().toDouble()
                /*
                    Although in XML we have android:inputType="numberDecimal"
                    the text property must be converted to a string and then that to a double
                    the casting/converting might fail if the user leaves the EditText blank
                    hence the try-catch block
                */
                tip = etTipPercentage.text.toString().toDouble()/100
                total = bill*(1+tip);
                //Toast.makeText(this,total.toString(),Toast.LENGTH_SHORT).show()
                tvTipAmount.text = String.format("Tip Amount: \t\t$%.2f",tip*bill) //\t is the tab escape sequence
                tvTotalAmount.text = String.format("Total Amount: \t$%.2f",total)  // %.2f display two decimal places
            }catch(e: Exception){
                Toast.makeText(this,"Enter number for bill and tip amounts.",Toast.LENGTH_SHORT).show()
            }

        }

        // clear results if user changes tip amount
        etTipPercentage.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(s: Editable) {}

            override fun beforeTextChanged(s: CharSequence, start: Int, count: Int, after: Int) {}

            override fun onTextChanged(s: CharSequence, start: Int, before: Int, count: Int) {
                tvTipAmount.text = "Tip Amount: ----------"
                tvTotalAmount.text = "Total Amount: ----------"
            }
        })

        // clear results if user changes bill amount
        etBillAmount.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(s: Editable) {}

            override fun beforeTextChanged(s: CharSequence, start: Int, count: Int, after: Int) {}

            override fun onTextChanged(s: CharSequence, start: Int, before: Int, count: Int) {
                tvTipAmount.text = "Tip Amount: ----------"
                tvTotalAmount.text = "Total Amount: ----------"
            }
        })

    }//end onCreate
}//end MainActivity class
